"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCurrentTheme = void 0;
var lib_1 = require("../../lib");
/**
 * Determines if the user has permissions, based on the permission kind value
 */
exports.getCurrentTheme = function () {
    // Return a promise
    return new Promise(function (resolve, reject) {
        // Get the current theme info
        lib_1.Web().Lists("Composed Looks").Items().query({
            Filter: "DisplayOrder eq 0 or Title eq 'Office'",
            OrderBy: ["DisplayOrder"],
            Select: ["DisplayOrder", "MasterPageUrl", "ThemeUrl", "Title"]
        }).execute(function (items) {
            var currentItem = items.results[0];
            var defaultItem = items.results[1];
            // See if the current theme info exists
            if (currentItem && currentItem["ThemeUrl"]) {
                // Get the theme information
                getThemeInfo(currentItem["ThemeUrl"].Url).then(resolve, reject);
            }
            else if (defaultItem && defaultItem["ThemeUrl"]) {
                // Get the theme information
                getThemeInfo(defaultItem["ThemeUrl"].Url).then(resolve, reject);
            }
            else {
                // Unable to determine the theme
                reject();
            }
        }, reject);
    });
};
// Gets the theme information for a color palette
var getThemeInfo = function (url) {
    if (url === void 0) { url = ""; }
    // Return a promise
    return new Promise(function (resolve, reject) {
        var themeInfo = {};
        // Ensure the url exists
        if (url.length == 0) {
            resolve(themeInfo);
            return;
        }
        // Get the file item
        lib_1.Site().RootWeb().getFileByUrl(url).execute(function (file) {
            // Read the contents
            file.content().execute(function (contents) {
                // Convert the xml
                var parser = new DOMParser();
                var xmlDoc = parser.parseFromString(String.fromCharCode.apply(null, new Uint8Array(contents)), "text/xml");
                // Get the colors and parse them
                var colors = xmlDoc.getElementsByTagName("s:color");
                for (var i = 0; i < colors.length; i++) {
                    var color = colors[i];
                    // Add the color information
                    themeInfo[color.getAttribute("name")] = "#" + color.getAttribute("value");
                }
                // Resolve the request
                resolve(themeInfo);
            }, reject);
        }, reject);
    });
};
